Index: trunk/psLib/src/math/psPolynomial.c
===================================================================
--- trunk/psLib/src/math/psPolynomial.c	(revision 1020)
+++ trunk/psLib/src/math/psPolynomial.c	(revision 1022)
@@ -7,6 +7,6 @@
  *  polynomials.  It also contains a Gaussian functions.
  *
- *  @version $Revision: 1.12 $ $Name: not supported by cvs2svn $
- *  @date $Date: 2004-06-14 19:32:42 $
+ *  @version $Revision: 1.13 $ $Name: not supported by cvs2svn $
+ *  @date $Date: 2004-06-14 19:40:14 $
  *
  *  Copyright 2004 Maui High Performance Computing Center, University of Hawaii
@@ -73,5 +73,5 @@
  Gaussian distribution as well.
  
- GUS: There is no way to seed the random generator.
+ NOTE: There is no way to seed the random generator.
  *****************************************************************************/
 psVector *psGaussianDev(float mean,
@@ -94,5 +94,5 @@
     }
 
     // GUS: Should I free r as well?
     return(gauss);
 }
@@ -320,5 +320,5 @@
     float xSum = 1.0;
 
     // GUS: Do we want to flag this case?
     if (myPoly->n == 0) {
         return(1.0);
@@ -646,5 +646,5 @@
     double xSum = 1.0;
 
     // GUS: Do we want to flag this case?
     if (myPoly->n == 0) {
         return(1.0);
@@ -94,5 +94,5 @@
     }
 
-    // GUS: Should I free r as well?
+    // NOTE: Should I free r as well?
     return(gauss);
 }
@@ -320,5 +320,5 @@
     float xSum = 1.0;
 
-    // GUS: Do we want to flag this case?
+    // NOTE: Do we want to flag this case?
     if (myPoly->n == 0) {
         return(1.0);
@@ -646,5 +646,5 @@
     double xSum = 1.0;
 
-    // GUS: Do we want to flag this case?
+    // NOTE: Do we want to flag this case?
     if (myPoly->n == 0) {
         return(1.0);
